==> deepin-font-manager_5.8.0.13.orig.tar.xz: deepin-font-manager-5.8.0.13/translations/deepin-font-manager_ne.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ne" version="2.1">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>सबै फन्टहरू</translation>
    </message>
    <message>
        <source>System</source>
        <translation>प्रणाली</translation>
    </message>
    <message>
        <source>User</source>
        <translation>प्रयोगकर्ता</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>मनपर्ने</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>सक्रिय</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>चीनियाँ</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>मोनोस्पेसिड</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>रद्द गर्नुहोस्</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>पुष्टि गर्नुहोस्</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>टुक्रिएको फाईल</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>समान संस्करण स्थापना भयो</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>प्रणाली फन्ट</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Ctrl+Shift+K</source>
        <translation>Ctrl+Shift+K</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>फन्टहरू</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>% 1 फन्ट स्थापना भयो</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>% 1 फन्ट स्थापना गरियो</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>Are you sure you want to delete this font?</source>
        <translation>के तपाईं निश्चित रूपमा यो फन्ट हटाउन चाहानुहुन्छ?</translation>
    </message>
    <message>
        <source>This font will not be available to applications</source>
        <translation>यो फन्ट अनुप्रयोगहरूमा उपलब्ध हुने छैन</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>यी फन्टहरू अनुप्रयोगहरूमा उपलब्ध हुँदैनन्</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <translation>हटाउनुहोस्</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>फन्टहरू हटाउँदै, कृपया प्रतीक्षा गर्नुहोस् ...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>फन्ट प्रमाणीकरण</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>बाहिर निस्कनुहोस्</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>जारी राख्नुहोस्</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>आफ्नो सपना सपना हुन नदिनुहोस्</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>आधारभूत जानकारी</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>शैली</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>प्रकार</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>संस्करण</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>वर्णन</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>अज्ञात</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>पुरा नाम</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Ps नाम</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>ट्रेडमार्क</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>फन्ट प्रबन्धक</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>फन्ट प्रबन्धकले प्रयोगकर्ताहरूलाई फन्ट स्थापना गर्न र प्रबन्ध गर्न मद्दत गर्दछ।</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>फन्टहरू लोड गर्दै, कृपया प्रतीक्षा गर्नुहोस् ...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>तपाईंको डेस्कटपमा फन्ट निर्यात गरियो</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>% 1 फन्टहरू तपाईंको डेस्कटपमा निर्यात गरियो</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>फन्ट थप्नुहोस्</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>सक्षम गर्नुहोस्</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>असक्षम गर्नुहोस्</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>हटाउनुहोस्</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>मनपर्ने</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>मनपर्ने छैन</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>विवरण</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>फाइल प्रबन्धकमा प्रदर्शन गर्नुहोस्</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>निर्यात</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>निस्क्रिय गरिएको</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>फन्टहरू निस्क्रिय पारिएका छन्</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Some fonts are not allowed to be disabled</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>फन्ट स्थापना गर्नुहोस्</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>प्रमाणित गर्दै ...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>अज्ञात</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>टुक्रिएको फाईल</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>स्थापित</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>स्थापना गरिएको छैन</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>फन्ट स्थापना गर्नुहोस्</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>खोज्नुहोस्</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>कुनै खोज परिणामहरू छैनन्</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>कुनै फन्टहरू छैनन्</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>मद्दत</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>सर्टकट प्रदर्शन गर्नुहोस्</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Page up</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Page down</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>हटाउनुहोस्</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>फन्ट थप्नुहोस्</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>मनपर्ने</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>मनपर्ने छैन</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>फन्ट जानकारी</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>इनपुट पूर्वावलोकन पाठ</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>टुक्रिएको फाईल</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_5.9.14.orig.tar.xz: deepin-font-manager-5.9.14/translations/deepin-font-manager_ne.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ne">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>सबै फन्टहरू</translation>
    </message>
    <message>
        <source>System</source>
        <translation>प्रणाली</translation>
    </message>
    <message>
        <source>User</source>
        <translation>प्रयोगकर्ता</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>मनपर्ने</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>सक्रिय</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>चीनियाँ</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>मोनोस्पेसिड</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>रद्द गर्नुहोस्</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>हटाउनुहोस्</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>सक्षम गर्नुहोस्</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>असक्षम गर्नुहोस्</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>रद्द गर्नुहोस्</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>टुक्रिएको फाईल</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>समान संस्करण स्थापना भयो</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>प्रणाली फन्ट</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>% 1 फन्ट स्थापना भयो</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>% 1 फन्ट स्थापना गरियो</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>यो फन्ट अनुप्रयोगहरूमा उपलब्ध हुने छैन</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>यी फन्टहरू अनुप्रयोगहरूमा उपलब्ध हुँदैनन्</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>हटाउनुहोस्</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>फन्टहरू हटाउँदै, कृपया प्रतीक्षा गर्नुहोस् ...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>फन्ट प्रमाणीकरण</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>बाहिर निस्कनुहोस्</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>जारी राख्नुहोस्</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>आधारभूत जानकारी</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>शैली</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>प्रकार</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>संस्करण</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>वर्णन</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>अज्ञात</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>पुरा नाम</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Ps नाम</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>ट्रेडमार्क</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>फन्ट प्रबन्धक</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>फन्ट प्रबन्धकले प्रयोगकर्ताहरूलाई फन्ट स्थापना गर्न र प्रबन्ध गर्न मद्दत गर्दछ।</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>फन्टहरू लोड गर्दै, कृपया प्रतीक्षा गर्नुहोस् ...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>तपाईंको डेस्कटपमा फन्ट निर्यात गरियो</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>% 1 फन्टहरू तपाईंको डेस्कटपमा निर्यात गरियो</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>फन्ट थप्नुहोस्</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>सक्षम गर्नुहोस्</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>असक्षम गर्नुहोस्</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>हटाउनुहोस्</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>मनपर्ने</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>मनपर्ने छैन</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>विवरण</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>फाइल प्रबन्धकमा प्रदर्शन गर्नुहोस्</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>निर्यात</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>निस्क्रिय गरिएको</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>फन्टहरू निस्क्रिय पारिएका छन्</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>फन्ट स्थापना गर्नुहोस्</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>प्रमाणित गर्दै ...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>अज्ञात</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>टुक्रिएको फाईल</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>स्थापित</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>स्थापना गरिएको छैन</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>फन्ट स्थापना गर्नुहोस्</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>खोज्नुहोस्</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>कुनै खोज परिणामहरू छैनन्</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>कुनै फन्टहरू छैनन्</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>मद्दत</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>सर्टकट प्रदर्शन गर्नुहोस्</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Page up</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Page down</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>हटाउनुहोस्</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>फन्ट थप्नुहोस्</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>मनपर्ने</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>मनपर्ने छैन</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>फन्ट जानकारी</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>इनपुट पूर्वावलोकन पाठ</translation>
    </message>
</context>
</TS>
